<footer class="fixed bottom primary-container">
    <div class="row align-center">
        <div class="max">
            <h6 class="small">Sandwitches</h6>
            <div class="small-text">© {% now "Y" %} Sandwitches Inc.</div>
        </div>
        <nav>
            version {{ version }}
            <a href="https://github.com/martynvdijke/sandwitches" target="_blank" class="circle transparent">
                <i>code</i>
            </a>
        </nav>
    </div>
</footer>
