# Generated by Django 6.0.1 on 2026-01-24 16:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "sandwitches",
            "0010_rename_is_approved_historicalrecipe_is_community_made_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalrecipe",
            name="is_community_made",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="recipe",
            name="is_community_made",
            field=models.BooleanField(default=False),
        ),
    ]
