# Generated by Django 6.0.1 on 2026-01-17 16:48

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0005_rating_comment"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="is_highlighted",
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name="recipe",
            name="is_highlighted",
            field=models.BooleanField(default=False),
        ),
    ]
