# Generated by Django 6.0.1 on 2026-01-21 09:53

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0007_historicalrecipe_price_recipe_price_order"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="daily_orders_count",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="historicalrecipe",
            name="max_daily_orders",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Max daily orders"
            ),
        ),
        migrations.AddField(
            model_name="recipe",
            name="daily_orders_count",
            field=models.PositiveIntegerField(default=0),
        ),
        migrations.AddField(
            model_name="recipe",
            name="max_daily_orders",
            field=models.PositiveIntegerField(
                blank=True, null=True, verbose_name="Max daily orders"
            ),
        ),
    ]
