# Generated by Django 6.0 on 2026-01-13 11:59

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalrecipe",
            name="servings",
            field=models.IntegerField(
                default=1, validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
        migrations.AddField(
            model_name="recipe",
            name="servings",
            field=models.IntegerField(
                default=1, validators=[django.core.validators.MinValueValidator(1)]
            ),
        ),
    ]
