# Generated by Django 6.0 on 2026-01-14 09:13

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0002_historicalrecipe_servings_recipe_servings"),
    ]

    operations = [
        migrations.CreateModel(
            name="Setting",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("site_name", models.CharField(default="Sandwitches", max_length=255)),
                ("site_description", models.TextField(blank=True)),
                ("email", models.EmailField(blank=True, max_length=254)),
                ("ai_connection_point", models.URLField(blank=True)),
                ("ai_model", models.CharField(blank=True, max_length=255)),
                ("ai_api_key", models.CharField(blank=True, max_length=255)),
            ],
            options={
                "verbose_name": "Site Settings",
            },
        ),
    ]
