# Generated by Django 6.0.1 on 2026-01-24 15:32

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0009_historicalrecipe_is_approved_recipe_is_approved"),
    ]

    operations = [
        migrations.RenameField(
            model_name="historicalrecipe",
            old_name="is_approved",
            new_name="is_community_made",
        ),
        migrations.RenameField(
            model_name="recipe",
            old_name="is_approved",
            new_name="is_community_made",
        ),
    ]
