# Generated by Django 6.0 on 2026-01-14 10:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("sandwitches", "0004_alter_setting_ai_api_key_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="rating",
            name="comment",
            field=models.TextField(blank=True),
        ),
    ]
